@@ -17,6 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include "gconf-database.h"
 #include "gconf-listeners.h"
 #include "gconf-sources.h"
@@ -1008,7 +1009,7 @@ gconf_database_schedule_sync(GConfDatabase* db)
   else
     {
       /* 1 minute timeout */
-      db->sync_timeout = g_timeout_add(60000, (GSourceFunc)gconf_database_sync_timeout, db);
+      db->sync_timeout = g_timeout_add_seconds(60, (GSourceFunc)gconf_database_sync_timeout, db);
     }
 }
 
@@ -1261,11 +1262,10 @@ gconf_database_notify_listeners (GConfDatabase       *db,
 
   g_slist_free (closure.dead);
 
-  if (notify_others)
+  if (modified_sources)
     {
-      g_return_if_fail (modified_sources != NULL);
-
-      gconfd_notify_other_listeners (db, modified_sources, key);
+      if (notify_others)
+          gconfd_notify_other_listeners (db, modified_sources, key);
 
       g_list_free (modified_sources->sources);
       g_free (modified_sources);
@@ -1722,6 +1722,18 @@ gconf_database_clear_cache (GConfDatabase  *db,
   gconf_sources_clear_cache(db->sources);
 }
 
+void
+gconf_database_clear_cache_for_sources (GConfDatabase  *db,
+					GConfSources   *sources,
+					GError        **err)
+{
+  g_assert(db->listeners != NULL);
+
+  db->last_access = time(NULL);
+
+  gconf_sources_clear_cache_for_sources(db->sources, sources);
+}
+
 const gchar *
 gconf_database_get_persistent_name (GConfDatabase *db)
 {
