@@ -29,10 +29,9 @@
 #include <config.h>
 #include <libintl.h>
 
-#define _(String) dgettext (GETTEXT_PACKAGE, String)
-#define N_(String) (String)
-
 #include <glib.h>
+#include <glib/gstdio.h>
+#include <glib/gi18n-lib.h>
 #include "gconf-error.h"
 #include "gconf-value.h"
 #include "gconf-engine.h"
@@ -44,9 +43,6 @@
 #define DEV_NULL "NUL:"
 
 #include <sys/stat.h>
-#include <io.h>
-
-#define mkdir(path, mode) _mkdir (path)
 
 #ifndef S_IRWXU
 #define S_IRWXU (_S_IREAD|_S_IWRITE|_S_IEXEC)
@@ -59,27 +55,27 @@
 #endif
 
 #undef GCONF_LOCALE_DIR
-extern const char *gconf_win32_locale_dir;
-#define GCONF_LOCALE_DIR gconf_win32_locale_dir
+const char *_gconf_win32_get_locale_dir (void) G_GNUC_CONST;
+#define GCONF_LOCALE_DIR _gconf_win32_get_locale_dir ()
 
 #undef GCONF_CONFDIR
-extern const char *gconf_win32_confdir;
-#define GCONF_CONFDIR gconf_win32_confdir
+const char *_gconf_win32_get_confdir (void) G_GNUC_CONST;
+#define GCONF_CONFDIR _gconf_win32_get_confdir ()
 
 #undef GCONF_ETCDIR
-extern const char *gconf_win32_etcdir;
-#define GCONF_ETCDIR gconf_win32_etcdir
+const char *_gconf_win32_get_etcdir (void) G_GNUC_CONST;
+#define GCONF_ETCDIR _gconf_win32_get_etcdir ()
 
 #undef GCONF_SERVERDIR
-extern const char *gconf_win32_serverdir;
-#define GCONF_SERVERDIR gconf_win32_serverdir
+const char *_gconf_win32_get_serverdir (void) G_GNUC_CONST;
+#define GCONF_SERVERDIR _gconf_win32_get_serverdir ()
 
 #undef GCONF_BACKEND_DIR
-extern const char *gconf_win32_backend_dir;
-#define GCONF_BACKEND_DIR gconf_win32_backend_dir
+const char *_gconf_win32_get_backend_dir (void) G_GNUC_CONST;
+#define GCONF_BACKEND_DIR _gconf_win32_get_backend_dir ()
 
-char *gconf_win32_replace_prefix (const char *configure_time_path);
-const char *gconf_win32_get_home_dir (void);
+char *_gconf_win32_replace_prefix (const char *configure_time_path);
+const char *_gconf_win32_get_home_dir (void);
 
 #else
 
@@ -92,17 +88,6 @@ const char *gconf_win32_get_home_dir (void);
 gchar*       gconf_key_directory  (const gchar* key);
 const gchar* gconf_key_key        (const gchar* key);
 
-/* These file tests are in libgnome, I cut-and-pasted them */
-enum {
-  GCONF_FILE_EXISTS=(1<<0)|(1<<1)|(1<<2), /*any type of file*/
-  GCONF_FILE_ISFILE=1<<0,
-  GCONF_FILE_ISLINK=1<<1,
-  GCONF_FILE_ISDIR=1<<2
-};
-
-gboolean gconf_file_test   (const gchar* filename, int test);
-gboolean gconf_file_exists (const gchar* filename);
-
 GConfValue*  gconf_value_from_corba_value            (const ConfigValue *value);
 ConfigValue* gconf_corba_value_from_gconf_value      (const GConfValue  *value);
 void         gconf_fill_corba_value_from_gconf_value (const GConfValue  *value,
@@ -283,13 +268,6 @@ gboolean gconf_CORBA_Object_equal (gconstpointer a,
                                    gconstpointer b);
 guint    gconf_CORBA_Object_hash  (gconstpointer key);
 
-
-/* FIXME move to public eventually */
-gboolean    gconf_entry_equal (const GConfEntry *a,
-                               const GConfEntry *b);
-int         gconf_value_compare (const GConfValue *value_a,
-                                 const GConfValue *value_b);
-
 GConfValue* gconf_schema_steal_default_value (GConfSchema *schema);
 
 void gconf_value_set_string_nocopy (GConfValue *value,
