@@ -17,6 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include "gconf-listeners.h"
 #include "gconf.h"
 
@@ -57,7 +58,7 @@ struct _Listener {
 typedef struct _LTable LTable;
 
 struct _LTable {
-  GNode* tree; /* Represents the config "filesystem" namespace. 
+  GNode* tree; /* Represents the configuration "filesystem" namespace. 
                 *  Kept sorted. 
                 */
   GPtrArray* listeners; /* Listeners are also kept in a flat array here, indexed by connection number */
@@ -366,9 +367,10 @@ ltable_insert(LTable* lt, const gchar* where, Listener* l)
 
       while (across != NULL)
         {
-          LTableEntry* lte = across->data;
           int cmp;
 
+          lte = across->data;
+
           cmp = strcmp(lte->name, dirnames[i]);
 
           if (cmp == 0)
